@@ -65,11 +65,18 @@ class Checkbox(BaseConsoleRender):
             yield choice, selector + " " + symbol, color
 
     def process_input(self, pressed):
+        question = self.question
         if pressed == key.UP:
-            self.current = max(0, self.current - 1)
+            if question.carousel and self.current == 0:
+                self.current = len(question.choices) - 1
+            else:
+                self.current = max(0, self.current - 1)
             return
         elif pressed == key.DOWN:
-            self.current = min(len(self.question.choices) - 1, self.current + 1)
+            if question.carousel and self.current == len(question.choices) - 1:
+                self.current = 0
+            else:
+                self.current = min(len(self.question.choices) - 1, self.current + 1)
             return
         elif pressed == key.SPACE:
             if self.current in self.selection:
